pub struct OrphanedEntry {
pub version: Version,
pub recorded_ref: String,
}Expand description
Orphaned entry: a Pending ledger entry whose backing ref is absent.
For GitTag entries the tag does not exist in git. For Snapshot entries
no tarball with the recorded SHA-256 exists in the snapshot store.
Fields
version: VersionVersion of the orphaned entry.
recorded_ref: StringThe tag ref recorded in the ledger (which does not exist).